import { create } from 'zustand';
import { ImagePickerAsset } from 'expo-image-picker';

interface User {
  user_id: string;
  first_name: string;
  last_name: string;
  avatar?: string;
  flag1?: string;
}

interface GroupChatStore {
  selectedUsers: User[] | [];
  image: ImagePickerAsset | null;
  groupName: string;
  description: string;
  addUser: (user: User) => void;
  removeUser: (userId: string) => void;
  setImage: (image: ImagePickerAsset | null) => void;
  setGroupName: (name: string) => void;
  setDescription: (desc: string) => void;
  clearStore: () => void;
}

export const useGroupChatStore = create<GroupChatStore>((set) => ({
  selectedUsers: [],
  image: null,
  groupName: '',
  description: '',
  addUser: (user) => set((state) => ({ selectedUsers: [user, ...state.selectedUsers] })),
  removeUser: (userId) =>
    set((state) => ({
      selectedUsers: state.selectedUsers.filter((user) => user.user_id !== userId)
    })),
  setImage: (image) => set({ image }),
  setGroupName: (name) => set({ groupName: name }),
  setDescription: (desc) => set({ description: desc }),
  clearStore: () =>
    set({
      selectedUsers: [],
      image: null,
      groupName: '',
      description: ''
    })
}));
